@@ -15,6 +15,10 @@ class SearchFilters:
     def Media():
         return "Media"
 
+    @staticmethod
+    def Lists():
+        return "Lists"
+
 
 class TweetConversationFilters:
     """
@@ -28,3 +32,12 @@ class TweetConversationFilters:
     def PeopleYouFollow():
         return "Community"
 
+class CommunityTweets:
+    @staticmethod
+    def Top():
+        return "Top"
+
+class CommunityMembers:
+    @staticmethod
+    def Moderators():
+        return "Mods"
