@@ -1,5 +1,4 @@
-import time
-from . import Tweet, Excel, User, deprecated
+from . import Tweet, Excel, User, List
 from .base import BaseGeneratorClass
 from .twDataTypes import SelfThread
 
@@ -9,14 +8,17 @@ class Search(BaseGeneratorClass):
         "tweet": Tweet,
         "homeConversation": SelfThread,
         "profile": SelfThread,
-        "user":User
+        "user": User,
+        "list": List
     }
+    _RESULT_ATTR = "results"
 
     def __init__(self, keyword, client, pages=1, filter_=None, wait_time=2, cursor=None):
         super().__init__()
         self.results = []
         self.keyword = keyword
         self.cursor = cursor
+        self.cursor_top = cursor
         self.is_next_page = True
         self.client = client
         self.pages = pages
@@ -25,28 +27,17 @@ class Search(BaseGeneratorClass):
 
     def __repr__(self):
         return "Search(keyword={}, count={}, filter={})".format(
-            self.keyword,len(self.results),self.filter
+            self.keyword, len(self.results), self.filter
         )
 
-    def get_next_page(self):
-        if self.is_next_page:
-            response = self.client.http.perform_search(self.keyword, self.cursor, self.filter)
-            thisTweets = self._parse_response(response)
-
-            self['is_next_page'] = self.is_next_page
-            self['cursor'] = self.cursor
-
-            return thisTweets
-
-        return []
-
-    def _get_target_object(self, tweet):
-        entry_type = str(tweet['entryId']).split("-")[0]
-        return self.OBJECTS_TYPES.get(entry_type)
-
-    def _parse_response(self, response):
+    def get_page(self, cursor):
         thisObjects = []
+        response = self.client.http.perform_search(self.keyword, cursor, self.filter)
         entries = self._get_entries(response)
+
+        if self.filter == "Lists":
+            entries = self._get_list_entries(entries)
+
         for entry in entries:
             object_type = self._get_target_object(entry)
 
@@ -54,29 +45,32 @@ class Search(BaseGeneratorClass):
                 if object_type is None:
                     continue
 
-                parsed = object_type(entry, self.client, None)
-                thisObjects.append(parsed)
-                self.results.append(parsed)
+                parsed = object_type(self.client, entry, None)
+                if parsed:
+                    thisObjects.append(parsed)
             except:
                 pass
 
-                self['results'] = self.results
+        cursor = self._get_cursor_(response)
+        cursor_top = self._get_cursor_(response, "Top")
 
-        self.is_next_page = self._get_cursor(response)
-        return thisObjects
+        return thisObjects, cursor, cursor_top
+
+    def _get_target_object(self, tweet):
+        entry_type = str(tweet['entryId']).split("-")[0]
+        return self.OBJECTS_TYPES.get(entry_type)
+
+    @staticmethod
+    def _get_list_entries(entries):
+        results = []
+        for entry in entries:
+            if str(entry['entryId']).split("-")[0] == "list":
+                for item in entry['content']['items']:
+                    results.append(item)
+        return results
 
     def to_xlsx(self, filename=None):
         if self.filter == "users":
             return AttributeError("to_xlsx with 'users' filter isn't supported yet")
 
         return Excel(self.results, f"search-{self.keyword}", filename)
-
-    def __getitem__(self, index):
-        if isinstance(index, str):
-            return getattr(self, index)
-
-        return self.results[index]
-
-    def __iter__(self):
-        for _result in self.results:
-            yield _result
