@@ -1,24 +1,28 @@
 import base64
+import datetime
 import hashlib
+import inspect
 import os.path
 import random
+import re
 import string
 import sys
 import uuid
+from dateutil import parser as date_parser
 from .exceptions_ import AuthenticationRequired
 
+GUEST_TOKEN_REGEX = re.compile("gt=(.*?);")
 MIME_TYPES = {
     "png": "image/png",
     "jpg": "image/jpeg",
     "jfif": "image/jpeg",
     "jpeg": "image/jpeg",
     "gif": "image/gif",
-    "webp": "image/webp"
+    "webp": "image/webp",
+    "mp4": "video/mp4",
+    "mov": "video/quicktime",
+    "m4v": "video/x-m4v"
 }
-# "mp4": "video/mp4",
-# "mov": "video/quicktime",
-# "m4v": "video/x-m4v"
-
 
 WORKBOOK_HEADERS = ['Date', 'Author', 'id', 'text', 'is_retweet', 'is_reply', 'language', 'likes',
                     'retweet_count', 'source', 'medias', 'user_mentioned', 'urls', 'hashtags', 'symbols']
@@ -29,29 +33,46 @@ SENSITIVE_MEDIA_TAGS = ['adult_content', 'graphic_violence', 'other']
 def AuthRequired(cls):
     def method_wrapper_decorator(func):
         def wrapper(self, *args, **kwargs):
-            if self.user is None:
+            if self.me is None:
                 raise AuthenticationRequired(200, "GenericForbidden", None)
 
             return func(self, *args, **kwargs)
 
         return wrapper
 
-    for name, method in vars(cls).items():
-        if name != "__init__" and callable(method):
-            setattr(cls, name, method_wrapper_decorator(method))
-    return cls
+    if inspect.isclass(cls):
+        for name, method in vars(cls).items():
+            if name != "__init__" and callable(method):
+                setattr(cls, name, method_wrapper_decorator(method))
+        return cls
+    return method_wrapper_decorator(cls)
+
+
+def replace_between_indexes(original_string, from_index, to_index, replacement_text):
+    new_string = original_string[:from_index] + replacement_text + original_string[to_index:]
+    return new_string
 
 
 def decodeBase64(encoded_string):
     return str(base64.b64decode(bytes(encoded_string, "utf-8")))[2:-1]
 
 
-def bar_progress(current, total, width=80):
-    progress_message = "Downloading: %d%% [%d / %d] bytes" % (current / total * 100, current, total)
+def bar_progress(filename, total, current, width=80):
+    progress_message = f"[{filename}] Downloading: %d%% [%d / %d] bytes" % (current / total * 100, current, total)
     sys.stdout.write("\r" + progress_message)
     sys.stdout.flush()
 
 
+def parse_wait_time(wait_time):
+    if not wait_time:
+        return 0
+
+    if isinstance(wait_time, (tuple, list)):
+        return random.randint(*wait_time)
+
+    return int(wait_time)
+
+
 def custom_json(self):
     try:
         return self.json()
@@ -78,9 +99,10 @@ def create_query_id():
 
 
 def check_if_file_is_image(file):
-    if not os.path.exists(file):
+    if not os.path.exists(file) and not str(file).startswith("https://"):
         raise ValueError("Path {} doesn't exists".format(file))
 
+    file = file.split("?")[0]
     file_extension = file.split(".")[-1]
 
     if file_extension not in list(MIME_TYPES.keys()):
@@ -96,6 +118,9 @@ def get_random_string(length):
 
 
 def calculate_md5(file_path):
+    if str(file_path).startswith("https://"):
+        return None
+
     md5_hash = hashlib.md5()
     with open(file_path, "rb") as file:
         for chunk in iter(lambda: file.read(4096), b""):
@@ -121,6 +146,7 @@ def check_sensitive_media_tags(tags):
 
 def find_objects(obj, key, value, recursive=True, none_value=None):
     results = []
+
     def find_matching_objects(_obj, _key, _value):
         if isinstance(_obj, dict):
             if _key in _obj:
@@ -150,3 +176,30 @@ def find_objects(obj, key, value, recursive=True, none_value=None):
         return none_value
 
     return results
+
+
+def create_pool(duration: int, *choices):
+    data = {
+        "twitter:long:duration_minutes": duration,
+        "twitter:api:api:endpoint": "1",
+        "twitter:card": f"poll{len(choices)}choice_text_only"
+    }
+
+    for index, choice in enumerate(choices, start=1):
+        key = f"twitter:string:choice{index}_label"
+        data[key] = choice
+
+    return data
+
+
+def parse_time(time):
+    if not time:
+        return None
+
+    if isinstance(time, int) or str(time).isdigit():
+        try:
+            return datetime.datetime.fromtimestamp(int(time))
+        except (OSError, ValueError):
+            return datetime.datetime.fromtimestamp(int(time) / 1000)
+
+    return date_parser.parse(time)
\ No newline at end of file
